<?php

/**
 * This software is intended for use with Oxwall Free Community Software http://www.oxwall.org/ and is
 * licensed under The BSD license.

 * ---
 * Copyright (c) 2011, Oxwall Foundation
 * All rights reserved.

 * Redistribution and use in source and binary forms, with or without modification, are permitted provided that the
 * following conditions are met:
 *
 *  - Redistributions of source code must retain the above copyright notice, this list of conditions and
 *  the following disclaimer.
 *
 *  - Redistributions in binary form must reproduce the above copyright notice, this list of conditions and
 *  the following disclaimer in the documentation and/or other materials provided with the distribution.
 *
 *  - Neither the name of the Oxwall Foundation nor the names of its contributors may be used to endorse or promote products
 *  derived from this software without specific prior written permission.

 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES,
 * INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED
 * AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

/**
 * Main page
 *
 * @author Nurlan Dzhumakaliev <nurlanj@live.com>
 * @package ow_plugins.contactus.controllers
 * @since 1.0
 */
class CONTACTPRO_CTRL_Contact extends OW_ActionController
{

    public function index()
    {
        $this->setPageTitle(OW::getLanguage()->text('contactpro', 'index_page_title'));
        $this->setPageHeading(OW::getLanguage()->text('contactpro', 'index_page_heading'));
		
		$gd = OW::getDocument();
		$gr = OW::getRouter();
		$lang = OW::getLanguage();
		$config = OW::getConfig();
		$gpm = OW::getPluginManager();
		$email = $config->getValue('contactpro', 'email');
		$captcha = $config->getValue('contactpro', 'captcha');
		$theme = $config->getValue('contactpro', 'theme');
		$address = $config->getValue('contactpro', 'address');
		$phone = $config->getValue('contactpro', 'phone');
		$fb = $config->getValue('contactpro', 'fb');
		$tw = $config->getValue('contactpro', 'tw');
		$gplus = $config->getValue('contactpro', 'gplus');
		$yp = $config->getValue('contactpro', 'yp');
		$pinterest = $config->getValue('contactpro', 'pinterest');
		
		if($theme == 'dark'){
			$gd->addStyleSheet(OW::getPluginManager()->getPlugin('contactpro')->getStaticCssUrl() . 'style_dark.css');
		}else{
			$gd->addStyleSheet(OW::getPluginManager()->getPlugin('contactpro')->getStaticCssUrl() . 'style_light.css');
		}
		
		$this->assign('email', $email);
		$this->assign('captcha', $captcha);
		$this->assign('address', $address);
		$this->assign('phone', $phone);
		$this->assign('fb', $fb);
		$this->assign('tw', $tw);
		$this->assign('gplus', $gplus);
		$this->assign('yp', $yp);
		$this->assign('pinterest', $pinterest);

        $form = new Form('contact_form');

        $fieldFrom = new TextField('from');
		$fieldFrom->setHasInvitation(true);
        $fieldFrom->setInvitation($lang->text('contactpro', 'from_example'));
        $fieldFrom->setRequired();
        $fieldFrom->addValidator(new EmailValidator());
        
        if ( ow::getUser()->isAuthenticated() )
        {
            $fieldFrom->setValue( OW::getUser()->getEmail() );
        }
        
        $form->addElement($fieldFrom);
		
        $fieldFname = new TextField('fname');
		$fieldFname->setHasInvitation(true);
        $fieldFname->setInvitation($lang->text('contactpro', 'fname_example'));
        $fieldFname->setRequired();
        $form->addElement($fieldFname);
		
        $fieldLname = new TextField('lname');
		$fieldLname->setHasInvitation(true);
        $fieldLname->setInvitation($lang->text('contactpro', 'lname_example'));
        $fieldLname->setRequired();
        $form->addElement($fieldLname);

        $fieldSubject = new TextField('subject');
		$fieldSubject->setHasInvitation(true);
        $fieldSubject->setInvitation($lang->text('contactpro', 'subject_example'));
        $fieldSubject->setRequired();
        $form->addElement($fieldSubject);

        $fieldMessage = new Textarea('message');
		$fieldMessage->setHasInvitation(true);
        $fieldMessage->setInvitation($lang->text('contactpro', 'message_example'));
        $fieldMessage->setRequired();
        $form->addElement($fieldMessage);

		if( $captcha == 1 ){
			$fieldCaptcha = new CaptchaField('captcha');
			$fieldCaptcha->setLabel($this->text('contactpro', 'form_label_captcha'));
			$form->addElement($fieldCaptcha);
		}
		
        $submit = new Submit('send');
        $submit->setValue($this->text('contactus', 'form_label_submit'));
        $form->addElement($submit);

        $this->addForm($form);

        if ( OW::getRequest()->isPost() )
        {
            if ( $form->isValid($_POST) )
            {
                $data = $form->getValues();
				$name = $data['fname'] . ' ' . $data['lname'];
				if( $config->getValue('contactpro', 'sender') == '' ){
					$sender = $config->getValue('base', 'site_email');
				}else{
					$sender = $config->getValue('contactpro', 'sender');
				}
				$recipient = $data['from'];
				$subject = $data['subject'];
				$message = $data['message'];

				$mailer = OW::getMailer()->createMail();
				$mailer->addRecipientEmail($email);
				$mailer->setSender($recipient, $name);
				$mailer->setSubject($subject);
				$mailer->setTextContent($message);
				OW::getMailer()->addToQueue($mailer);
				
                $this->redirectToAction('sent');
            }
        }
    }

    public function sent()
    {
        $dept = null;

        if ( OW::getSession()->isKeySet('contactpro.dept') )
        {
            $dept = OW::getSession()->get('contactpro.dept');
            OW::getSession()->delete('contactpro.dept');
        }
        else
        {
            $this->redirectToAction('index');
        }

        $feedback = $this->text('contactpro', 'message_sent');
        $this->assign('feedback', $feedback);
    }

    private function text( $prefix, $key, array $vars = null )
    {
        return OW::getLanguage()->text($prefix, $key, $vars);
    }
}